Module docstrings

Module docstrings 

Utilities for parsing Python docstrings.

Functions

clean_space
Replace any non-whitespace characters from an indentation string within a Python docstring.
leading_space
Extract the leading whitespace from a line of text within a Python docstring.
leading_words
Extract the leading words from a line of text within a Python docstring.