ExceptHandlerRef

Enum ExceptHandlerRef 

pub enum ExceptHandlerRef<'a> {
    ExceptHandler(&'a ExceptHandlerExceptHandler),
}
See also excepthandler

Variants



ExceptHandler(&'a ExceptHandlerExceptHandler)

Implementations

Source

impl<'a> ExceptHandlerRef<'a>

pub const fn is_except_handler(&self) -> bool

Returns true if self is of variant ExceptHandler.

pub fn as_except_handler(&self) -> Option<&&'a ExceptHandlerExceptHandler>

Returns Some if self is a reference of variant ExceptHandler, and None otherwise.

pub fn as_mut_except_handler( &mut self, ) -> Option<&mut &'a ExceptHandlerExceptHandler>

Returns Some if self is a mutable reference of variant ExceptHandler, and None otherwise.

pub fn expect_except_handler(self) -> &'a ExceptHandlerExceptHandler
where Self: Debug,

Unwraps the value, yielding the content of ExceptHandler.

Panics

Panics if the value is not ExceptHandler, with a panic message including the content of self.

pub fn except_handler(self) -> Option<&'a ExceptHandlerExceptHandler>

Returns Some if self is of variant ExceptHandler, and None otherwise.