Expr

Enum Expr 

pub enum Expr {
Show 33 variants BoolOp(ExprBoolOp), Named(ExprNamed), BinOp(ExprBinOp), UnaryOp(ExprUnaryOp), Lambda(ExprLambda), If(ExprIf), Dict(ExprDict), Set(ExprSet), ListComp(ExprListComp), SetComp(ExprSetComp), DictComp(ExprDictComp), Generator(ExprGenerator), Await(ExprAwait), Yield(ExprYield), YieldFrom(ExprYieldFrom), Compare(ExprCompare), Call(ExprCall), FString(ExprFString), TString(ExprTString), StringLiteral(ExprStringLiteral), BytesLiteral(ExprBytesLiteral), NumberLiteral(ExprNumberLiteral), BooleanLiteral(ExprBooleanLiteral), NoneLiteral(ExprNoneLiteral), EllipsisLiteral(ExprEllipsisLiteral), Attribute(ExprAttribute), Subscript(ExprSubscript), Starred(ExprStarred), Name(ExprName), List(ExprList), Tuple(ExprTuple), Slice(ExprSlice), IpyEscapeCommand(ExprIpyEscapeCommand),
}
See also expr

Variants



BoolOp(ExprBoolOp)



Named(ExprNamed)



BinOp(ExprBinOp)



UnaryOp(ExprUnaryOp)



Lambda(ExprLambda)



If(ExprIf)



Dict(ExprDict)



Set(ExprSet)



ListComp(ExprListComp)



SetComp(ExprSetComp)



DictComp(ExprDictComp)



Generator(ExprGenerator)



Await(ExprAwait)



Yield(ExprYield)



YieldFrom(ExprYieldFrom)



Compare(ExprCompare)



Call(ExprCall)



FString(ExprFString)



TString(ExprTString)



StringLiteral(ExprStringLiteral)



BytesLiteral(ExprBytesLiteral)



NumberLiteral(ExprNumberLiteral)



BooleanLiteral(ExprBooleanLiteral)



NoneLiteral(ExprNoneLiteral)



EllipsisLiteral(ExprEllipsisLiteral)



Attribute(ExprAttribute)



Subscript(ExprSubscript)



Starred(ExprStarred)



Name(ExprName)



List(ExprList)



Tuple(ExprTuple)



Slice(ExprSlice)



IpyEscapeCommand(ExprIpyEscapeCommand)

Implementations

Source

impl Expr

pub const fn is_bool_op_expr(&self) -> bool

pub fn bool_op_expr(self) -> Option<ExprBoolOp>

pub fn expect_bool_op_expr(self) -> ExprBoolOp

pub fn as_bool_op_expr_mut(&mut self) -> Option<&mut ExprBoolOp>

pub fn as_bool_op_expr(&self) -> Option<&ExprBoolOp>

pub const fn is_named_expr(&self) -> bool

pub fn named_expr(self) -> Option<ExprNamed>

pub fn expect_named_expr(self) -> ExprNamed

pub fn as_named_expr_mut(&mut self) -> Option<&mut ExprNamed>

pub fn as_named_expr(&self) -> Option<&ExprNamed>

pub const fn is_bin_op_expr(&self) -> bool

pub fn bin_op_expr(self) -> Option<ExprBinOp>

pub fn expect_bin_op_expr(self) -> ExprBinOp

pub fn as_bin_op_expr_mut(&mut self) -> Option<&mut ExprBinOp>

pub fn as_bin_op_expr(&self) -> Option<&ExprBinOp>

pub const fn is_unary_op_expr(&self) -> bool

pub fn unary_op_expr(self) -> Option<ExprUnaryOp>

pub fn expect_unary_op_expr(self) -> ExprUnaryOp

pub fn as_unary_op_expr_mut(&mut self) -> Option<&mut ExprUnaryOp>

pub fn as_unary_op_expr(&self) -> Option<&ExprUnaryOp>

pub const fn is_lambda_expr(&self) -> bool

pub fn lambda_expr(self) -> Option<ExprLambda>

pub fn expect_lambda_expr(self) -> ExprLambda

pub fn as_lambda_expr_mut(&mut self) -> Option<&mut ExprLambda>

pub fn as_lambda_expr(&self) -> Option<&ExprLambda>

pub const fn is_if_expr(&self) -> bool

pub fn if_expr(self) -> Option<ExprIf>

pub fn expect_if_expr(self) -> ExprIf

pub fn as_if_expr_mut(&mut self) -> Option<&mut ExprIf>

pub fn as_if_expr(&self) -> Option<&ExprIf>

pub const fn is_dict_expr(&self) -> bool

pub fn dict_expr(self) -> Option<ExprDict>

pub fn expect_dict_expr(self) -> ExprDict

pub fn as_dict_expr_mut(&mut self) -> Option<&mut ExprDict>

pub fn as_dict_expr(&self) -> Option<&ExprDict>

pub const fn is_set_expr(&self) -> bool

pub fn set_expr(self) -> Option<ExprSet>

pub fn expect_set_expr(self) -> ExprSet

pub fn as_set_expr_mut(&mut self) -> Option<&mut ExprSet>

pub fn as_set_expr(&self) -> Option<&ExprSet>

pub const fn is_list_comp_expr(&self) -> bool

pub fn list_comp_expr(self) -> Option<ExprListComp>

pub fn expect_list_comp_expr(self) -> ExprListComp

pub fn as_list_comp_expr_mut(&mut self) -> Option<&mut ExprListComp>

pub fn as_list_comp_expr(&self) -> Option<&ExprListComp>

pub const fn is_set_comp_expr(&self) -> bool

pub fn set_comp_expr(self) -> Option<ExprSetComp>

pub fn expect_set_comp_expr(self) -> ExprSetComp

pub fn as_set_comp_expr_mut(&mut self) -> Option<&mut ExprSetComp>

pub fn as_set_comp_expr(&self) -> Option<&ExprSetComp>

pub const fn is_dict_comp_expr(&self) -> bool

pub fn dict_comp_expr(self) -> Option<ExprDictComp>

pub fn expect_dict_comp_expr(self) -> ExprDictComp

pub fn as_dict_comp_expr_mut(&mut self) -> Option<&mut ExprDictComp>

pub fn as_dict_comp_expr(&self) -> Option<&ExprDictComp>

pub const fn is_generator_expr(&self) -> bool

pub fn generator_expr(self) -> Option<ExprGenerator>

pub fn expect_generator_expr(self) -> ExprGenerator

pub fn as_generator_expr_mut(&mut self) -> Option<&mut ExprGenerator>

pub fn as_generator_expr(&self) -> Option<&ExprGenerator>

pub const fn is_await_expr(&self) -> bool

pub fn await_expr(self) -> Option<ExprAwait>

pub fn expect_await_expr(self) -> ExprAwait

pub fn as_await_expr_mut(&mut self) -> Option<&mut ExprAwait>

pub fn as_await_expr(&self) -> Option<&ExprAwait>

pub const fn is_yield_expr(&self) -> bool

pub fn yield_expr(self) -> Option<ExprYield>

pub fn expect_yield_expr(self) -> ExprYield

pub fn as_yield_expr_mut(&mut self) -> Option<&mut ExprYield>

pub fn as_yield_expr(&self) -> Option<&ExprYield>

pub const fn is_yield_from_expr(&self) -> bool

pub fn yield_from_expr(self) -> Option<ExprYieldFrom>

pub fn expect_yield_from_expr(self) -> ExprYieldFrom

pub fn as_yield_from_expr_mut(&mut self) -> Option<&mut ExprYieldFrom>

pub fn as_yield_from_expr(&self) -> Option<&ExprYieldFrom>

pub const fn is_compare_expr(&self) -> bool

pub fn compare_expr(self) -> Option<ExprCompare>

pub fn expect_compare_expr(self) -> ExprCompare

pub fn as_compare_expr_mut(&mut self) -> Option<&mut ExprCompare>

pub fn as_compare_expr(&self) -> Option<&ExprCompare>

pub const fn is_call_expr(&self) -> bool

pub fn call_expr(self) -> Option<ExprCall>

pub fn expect_call_expr(self) -> ExprCall

pub fn as_call_expr_mut(&mut self) -> Option<&mut ExprCall>

pub fn as_call_expr(&self) -> Option<&ExprCall>

pub const fn is_f_string_expr(&self) -> bool

pub fn f_string_expr(self) -> Option<ExprFString>

pub fn expect_f_string_expr(self) -> ExprFString

pub fn as_f_string_expr_mut(&mut self) -> Option<&mut ExprFString>

pub fn as_f_string_expr(&self) -> Option<&ExprFString>

pub const fn is_t_string_expr(&self) -> bool

pub fn t_string_expr(self) -> Option<ExprTString>

pub fn expect_t_string_expr(self) -> ExprTString

pub fn as_t_string_expr_mut(&mut self) -> Option<&mut ExprTString>

pub fn as_t_string_expr(&self) -> Option<&ExprTString>

pub const fn is_string_literal_expr(&self) -> bool

pub fn string_literal_expr(self) -> Option<ExprStringLiteral>

pub fn expect_string_literal_expr(self) -> ExprStringLiteral

pub fn as_string_literal_expr_mut(&mut self) -> Option<&mut ExprStringLiteral>

pub fn as_string_literal_expr(&self) -> Option<&ExprStringLiteral>

pub const fn is_bytes_literal_expr(&self) -> bool

pub fn bytes_literal_expr(self) -> Option<ExprBytesLiteral>

pub fn expect_bytes_literal_expr(self) -> ExprBytesLiteral

pub fn as_bytes_literal_expr_mut(&mut self) -> Option<&mut ExprBytesLiteral>

pub fn as_bytes_literal_expr(&self) -> Option<&ExprBytesLiteral>

pub const fn is_number_literal_expr(&self) -> bool

pub fn number_literal_expr(self) -> Option<ExprNumberLiteral>

pub fn expect_number_literal_expr(self) -> ExprNumberLiteral

pub fn as_number_literal_expr_mut(&mut self) -> Option<&mut ExprNumberLiteral>

pub fn as_number_literal_expr(&self) -> Option<&ExprNumberLiteral>

pub const fn is_boolean_literal_expr(&self) -> bool

pub fn boolean_literal_expr(self) -> Option<ExprBooleanLiteral>

pub fn expect_boolean_literal_expr(self) -> ExprBooleanLiteral

pub fn as_boolean_literal_expr_mut(&mut self) -> Option<&mut ExprBooleanLiteral>

pub fn as_boolean_literal_expr(&self) -> Option<&ExprBooleanLiteral>

pub const fn is_none_literal_expr(&self) -> bool

pub fn none_literal_expr(self) -> Option<ExprNoneLiteral>

pub fn expect_none_literal_expr(self) -> ExprNoneLiteral

pub fn as_none_literal_expr_mut(&mut self) -> Option<&mut ExprNoneLiteral>

pub fn as_none_literal_expr(&self) -> Option<&ExprNoneLiteral>

pub const fn is_ellipsis_literal_expr(&self) -> bool

pub fn ellipsis_literal_expr(self) -> Option<ExprEllipsisLiteral>

pub fn expect_ellipsis_literal_expr(self) -> ExprEllipsisLiteral

pub fn as_ellipsis_literal_expr_mut( &mut self, ) -> Option<&mut ExprEllipsisLiteral>

pub fn as_ellipsis_literal_expr(&self) -> Option<&ExprEllipsisLiteral>

pub const fn is_attribute_expr(&self) -> bool

pub fn attribute_expr(self) -> Option<ExprAttribute>

pub fn expect_attribute_expr(self) -> ExprAttribute

pub fn as_attribute_expr_mut(&mut self) -> Option<&mut ExprAttribute>

pub fn as_attribute_expr(&self) -> Option<&ExprAttribute>

pub const fn is_subscript_expr(&self) -> bool

pub fn subscript_expr(self) -> Option<ExprSubscript>

pub fn expect_subscript_expr(self) -> ExprSubscript

pub fn as_subscript_expr_mut(&mut self) -> Option<&mut ExprSubscript>

pub fn as_subscript_expr(&self) -> Option<&ExprSubscript>

pub const fn is_starred_expr(&self) -> bool

pub fn starred_expr(self) -> Option<ExprStarred>

pub fn expect_starred_expr(self) -> ExprStarred

pub fn as_starred_expr_mut(&mut self) -> Option<&mut ExprStarred>

pub fn as_starred_expr(&self) -> Option<&ExprStarred>

pub const fn is_name_expr(&self) -> bool

pub fn name_expr(self) -> Option<ExprName>

pub fn expect_name_expr(self) -> ExprName

pub fn as_name_expr_mut(&mut self) -> Option<&mut ExprName>

pub fn as_name_expr(&self) -> Option<&ExprName>

pub const fn is_list_expr(&self) -> bool

pub fn list_expr(self) -> Option<ExprList>

pub fn expect_list_expr(self) -> ExprList

pub fn as_list_expr_mut(&mut self) -> Option<&mut ExprList>

pub fn as_list_expr(&self) -> Option<&ExprList>

pub const fn is_tuple_expr(&self) -> bool

pub fn tuple_expr(self) -> Option<ExprTuple>

pub fn expect_tuple_expr(self) -> ExprTuple

pub fn as_tuple_expr_mut(&mut self) -> Option<&mut ExprTuple>

pub fn as_tuple_expr(&self) -> Option<&ExprTuple>

pub const fn is_slice_expr(&self) -> bool

pub fn slice_expr(self) -> Option<ExprSlice>

pub fn expect_slice_expr(self) -> ExprSlice

pub fn as_slice_expr_mut(&mut self) -> Option<&mut ExprSlice>

pub fn as_slice_expr(&self) -> Option<&ExprSlice>

pub const fn is_ipy_escape_command_expr(&self) -> bool

pub fn ipy_escape_command_expr(self) -> Option<ExprIpyEscapeCommand>

pub fn expect_ipy_escape_command_expr(self) -> ExprIpyEscapeCommand

pub fn as_ipy_escape_command_expr_mut( &mut self, ) -> Option<&mut ExprIpyEscapeCommand>

pub fn as_ipy_escape_command_expr(&self) -> Option<&ExprIpyEscapeCommand>

Source

impl Expr

pub fn is_literal_expr(&self) -> bool

Returns true if the expression is a literal expression.

A literal expression is either a string literal, bytes literal, integer, float, complex number, boolean, None, or ellipsis (...).

pub fn as_literal_expr(&self) -> Option<LiteralExpressionRef<'_>>

Returns LiteralExpressionRef if the expression is a literal expression.

pub fn precedence(&self) -> OperatorPrecedence

Return the OperatorPrecedence of this expression