pub enum IpyEscapeKind {
Shell,
ShCap,
Help,
Help2,
Magic,
Magic2,
Quote,
Quote2,
Paren,
}Expand description
The kind of escape command as defined in IPython Syntax in the IPython codebase.
Variants
Shell
Send line to underlying system shell (!).
ShCap
Send line to system shell and capture output (!!).
Help
Show help on object (?).
Help2
Show help on object, with extra verbosity (??).
Magic
Call magic function (%).
Magic2
Call cell magic function (%%).
Quote
Call first argument with rest of line as arguments after splitting on whitespace
and quote each as string (,).
Quote2
Call first argument with rest of line as an argument quoted as a single string (;).
Paren
Call first argument with rest of line as arguments (/).
Implementations