Number

Enum Number 

pub enum Number {
    Int(Int),
    Float(f64),
    Complex {
        real: f64,
        imag: f64,
    },
}

Variants



Int(Int)



Float(f64)



Complex

Fields

real: f64
imag: f64

Implementations

Source

impl Number

pub const fn is_int(&self) -> bool

Returns true if self is of variant Int.

pub fn as_int(&self) -> Option<&Int>

Returns Some if self is a reference of variant Int, and None otherwise.

pub fn as_mut_int(&mut self) -> Option<&mut Int>

Returns Some if self is a mutable reference of variant Int, and None otherwise.

pub fn expect_int(self) -> Int
where Self: Debug,

Unwraps the value, yielding the content of Int.

Panics

Panics if the value is not Int, with a panic message including the content of self.

pub fn int(self) -> Option<Int>

Returns Some if self is of variant Int, and None otherwise.

pub const fn is_float(&self) -> bool

Returns true if self is of variant Float.

pub fn as_float(&self) -> Option<&f64>

Returns Some if self is a reference of variant Float, and None otherwise.

pub fn as_mut_float(&mut self) -> Option<&mut f64>

Returns Some if self is a mutable reference of variant Float, and None otherwise.

pub fn expect_float(self) -> f64
where Self: Debug,

Unwraps the value, yielding the content of Float.

Panics

Panics if the value is not Float, with a panic message including the content of self.

pub fn float(self) -> Option<f64>

Returns Some if self is of variant Float, and None otherwise.

pub const fn is_complex(&self) -> bool

Returns true if self is of variant Complex.