Module find_node

Module find_node 

Structs

CoveringNode
The node with a minimal range that fully contains the search range.

Functions

covering_node
Returns the node with a minimal range that fully contains range.