contains_effect

Function contains_effect 

pub fn contains_effect<F>(expr: &Expr, is_builtin: F) -> bool
where F: Fn(&str) -> bool,
Return true if the Expr contains an expression that appears to include a side-effect (like a function call).

Accepts a closure that determines whether a given name (e.g., "list") is a Python builtin.