from_relative_import

Function from_relative_import 

pub fn from_relative_import<'a>(
    module: &'a [String],
    import: &[&'a str],
    tail: &[&'a str],
) -> Option<QualifiedName<'a>>
Format the call path for a relative import, or None if the relative import extends beyond the root module.