pub fn map_subscript(expr: &Expr) -> &ExprExpand description
Given an Expr that can be a ExprSubscript or not
(like an annotation that may be generic or not), return the underlying expr.
pub fn map_subscript(expr: &Expr) -> &ExprGiven an Expr that can be a ExprSubscript or not
(like an annotation that may be generic or not), return the underlying expr.