Module identifier

Module identifier 

Extract TextRange information from AST nodes.

For example, given:

try:
    ...
except Exception as e:
    ...

This module can be used to identify the TextRange of the except token.

Traits

Identifier

Functions

else_
Return the TextRange of the else token in a For or While statement.
except
Return the TextRange of the except token in an ExceptHandler.