pub fn elif_else_range(
clause: &ElifElseClause,
contents: &str,
) -> Option<TextRange>Expand description
Return the Range of the first Elif or Else token in an If statement.
pub fn elif_else_range(
clause: &ElifElseClause,
contents: &str,
) -> Option<TextRange>Return the Range of the first Elif or Else token in an If statement.