Module str_prefix

Module str_prefix 

Enums

AnyStringPrefix
Enumeration of all the possible valid prefixes prior to a Python string literal.
ByteStringPrefix
Enumeration of the valid prefixes a bytestring literal can have.
FStringPrefix
Enumeration of the valid prefixes an f-string literal can have.
StringLiteralPrefix
Enumerations of the valid prefixes a string literal can have.
TStringPrefix
Enumeration of the valid prefixes a t-string literal can have.