pub enum ByteStringPrefix {
Regular,
Raw {
uppercase_r: bool,
},
}Expand description
Enumeration of the valid prefixes a bytestring literal can have.
Variants
Regular
Just a regular bytestring with no other prefixes, e.g. b"foo"
Raw
A “raw” bytestring, that has an r or R prefix,
e.g. Rb"foo" or rb"foo"
Implementations