pub struct AnyStringFlags(/* private fields */);Implementations
Sourceimpl AnyStringFlags
impl AnyStringFlags
pub fn with_prefix(self, prefix: AnyStringPrefix) -> Self
pub fn new( prefix: AnyStringPrefix, quotes: Quote, triple_quotes: TripleQuotes, ) -> Self
Sourcepub const fn is_u_string(self) -> bool
pub const fn is_u_string(self) -> bool
Does the string have a u or U prefix?
Sourcepub const fn is_raw_string(self) -> bool
pub const fn is_raw_string(self) -> bool
Does the string have an r or R prefix?
Sourcepub const fn is_interpolated_string(self) -> bool
pub const fn is_interpolated_string(self) -> bool
Does the string have an f,F,t, or T prefix?
Sourcepub const fn is_byte_string(self) -> bool
pub const fn is_byte_string(self) -> bool
Does the string have a b or B prefix?
pub fn with_quote_style(self, quotes: Quote) -> Self
pub fn with_triple_quotes(self, triple_quotes: TripleQuotes) -> Self
pub fn with_unclosed(self, unclosed: bool) -> Self