pub struct ExprDict {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub items: Vec<DictItem>,
}Expand description
See also Dict
Fields
node_index: AtomicNodeIndexrange: TextRangeitems: Vec<DictItem>Implementations
Sourceimpl ExprDict
impl ExprDict
Sourcepub fn iter_keys(&self) -> DictKeyIterator<'_> ⓘ
pub fn iter_keys(&self) -> DictKeyIterator<'_> ⓘ
Returns an Iterator over the AST nodes representing the
dictionary’s keys.
Sourcepub fn iter_values(&self) -> DictValueIterator<'_> ⓘ
pub fn iter_values(&self) -> DictValueIterator<'_> ⓘ
Returns an Iterator over the AST nodes representing the
dictionary’s values.
Sourcepub fn key(&self, n: usize) -> Option<&Expr>
pub fn key(&self, n: usize) -> Option<&Expr>
Returns the AST node representing the nth key of this dictionary.
Panics: If the index n is out of bounds.
Sourcepub fn value(&self, n: usize) -> &Expr
pub fn value(&self, n: usize) -> &Expr
Returns the AST node representing the nth value of this dictionary.
Panics: If the index n is out of bounds.
pub fn iter(&self) -> Iter<'_, DictItem>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool