pub struct ExprFString {
pub node_index: AtomicNodeIndex,
pub range: TextRange,
pub value: FStringValue,
}Expand description
An AST node that represents either a single-part f-string literal or an implicitly concatenated f-string literal.
This type differs from the original Python AST JoinedStr in that it
doesn’t join the implicitly concatenated parts into a single string. Instead,
it keeps them separate and provide various methods to access the parts.
See also JoinedStr
Fields
node_index: AtomicNodeIndexrange: TextRangevalue: FStringValueImplementations
Sourceimpl ExprFString
impl ExprFString