pub struct FStringValue { /* private fields */ }Expand description
The value representing an ExprFString.
Implementations
Sourceimpl FStringValue
impl FStringValue
Sourcepub fn single(value: FString) -> Self
pub fn single(value: FString) -> Self
Creates a new f-string literal with a single FString part.
Sourcepub fn concatenated(values: Vec<FStringPart>) -> Self
pub fn concatenated(values: Vec<FStringPart>) -> Self
Creates a new f-string with the given values that represents an implicitly concatenated f-string.
Panics
Panics if values has less than 2 elements.
Use FStringValue::single instead.
Sourcepub fn is_implicit_concatenated(&self) -> bool
pub fn is_implicit_concatenated(&self) -> bool
Returns true if the f-string is implicitly concatenated, false otherwise.
Sourcepub fn as_slice(&self) -> &[FStringPart]
pub fn as_slice(&self) -> &[FStringPart]
Returns a slice of all the FStringParts contained in this value.
Sourcepub fn iter(&self) -> Iter<'_, FStringPart>
pub fn iter(&self) -> Iter<'_, FStringPart>
Returns an iterator over all the FStringParts contained in this value.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, FStringPart>
pub fn iter_mut(&mut self) -> IterMut<'_, FStringPart>
Returns an iterator over all the FStringParts contained in this value
that allows modification.
Sourcepub fn literals(&self) -> impl Iterator<Item = &StringLiteral>
pub fn literals(&self) -> impl Iterator<Item = &StringLiteral>
Returns an iterator over the StringLiteral parts contained in this value.
Note that this doesn’t recurse into the f-string parts. For example,
"foo" f"bar {x}" "baz" f"qux"Here, the string literal parts returned would be "foo" and "baz".
Sourcepub fn f_strings(&self) -> impl Iterator<Item = &FString>
pub fn f_strings(&self) -> impl Iterator<Item = &FString>
Returns an iterator over the FString parts contained in this value.
Note that this doesn’t recurse into the f-string parts. For example,
"foo" f"bar {x}" "baz" f"qux"Here, the f-string parts returned would be f"bar {x}" and f"qux".
Sourcepub fn elements(&self) -> impl Iterator<Item = &InterpolatedStringElement>
pub fn elements(&self) -> impl Iterator<Item = &InterpolatedStringElement>
Returns an iterator over all the InterpolatedStringElement contained in this value.
An f-string element is what makes up an FString i.e., it is either a
string literal or an expression. In the following example,
"foo" f"bar {x}" "baz" f"qux"The f-string elements returned would be string literal ("bar "),
expression (x) and string literal ("qux").
Sourcepub fn is_empty_literal(&self) -> bool
pub fn is_empty_literal(&self) -> bool
Returns true if the node represents an empty f-string literal.
Note that a FStringValue node will always have >= 1 FStringParts inside it.
This method checks whether the value of the concatenated parts is equal to the empty
f-string, not whether the f-string has 0 parts inside it.