pub struct Int(/* private fields */);Expand description
A Python integer literal. Represents both small (fits in an i64) and large integers.
Implementations
Sourceimpl Int
impl Int
pub const ZERO: Int
pub const ONE: Int
Sourcepub fn from_str_radix(
number: &str,
radix: u32,
token: &str,
) -> Result<Self, ParseIntError>
pub fn from_str_radix( number: &str, radix: u32, token: &str, ) -> Result<Self, ParseIntError>
Parse an Int from a string with a given radix, like 0x95D.
Takes, as input, the numerical portion (95D), the parsed base (16), and the entire
token (0x95D).
Sourcepub fn as_u8(&self) -> Option<u8>
pub fn as_u8(&self) -> Option<u8>
Return the Int as an u8, if it can be represented as that data type.
Sourcepub fn as_u16(&self) -> Option<u16>
pub fn as_u16(&self) -> Option<u16>
Return the Int as an u16, if it can be represented as that data type.
Sourcepub fn as_u32(&self) -> Option<u32>
pub fn as_u32(&self) -> Option<u32>
Return the Int as an u32, if it can be represented as that data type.
Sourcepub const fn as_u64(&self) -> Option<u64>
pub const fn as_u64(&self) -> Option<u64>
Return the Int as an u64, if it can be represented as that data type.
Sourcepub fn as_usize(&self) -> Option<usize>
pub fn as_usize(&self) -> Option<usize>
Return the Int as an usize, if it can be represented as that data type.
Sourcepub fn as_i8(&self) -> Option<i8>
pub fn as_i8(&self) -> Option<i8>
Return the Int as an i8, if it can be represented as that data type.
Sourcepub fn as_i16(&self) -> Option<i16>
pub fn as_i16(&self) -> Option<i16>
Return the Int as an i16, if it can be represented as that data type.