pub struct ParameterWithDefault {
pub range: TextRange,
pub node_index: AtomicNodeIndex,
pub parameter: Parameter,
pub default: Option<Box<Expr>>,
}Expand description
An alternative type of AST arg. This is used for each function argument that might have a default value.
Used by Arguments original type.
NOTE: This type is different from original Python AST.
Fields
range: TextRangenode_index: AtomicNodeIndexparameter: Parameterdefault: Option<Box<Expr>>Implementations
Sourceimpl ParameterWithDefault
impl ParameterWithDefault
pub fn default(&self) -> Option<&Expr>
pub const fn name(&self) -> &Identifier
pub fn annotation(&self) -> Option<&Expr>
Sourcepub fn uses_pep_484_positional_only_convention(&self) -> bool
pub fn uses_pep_484_positional_only_convention(&self) -> bool
Return true if the parameter name uses the pre-PEP-570 convention
(specified in PEP 484) to indicate to a type checker that it should be treated
as positional-only.