TStringFlags

Struct TStringFlags 

pub struct TStringFlags(/* private fields */);
Flags that can be queried to obtain information regarding the prefixes and quotes used for an f-string.

Note: This is identical to FStringFlags except that the implementation of the prefix method of the StringFlags trait returns a variant of AnyStringPrefix::Template.

Notes on usage

If you’re using a Generator from the ruff_python_codegen crate to generate a lint-rule fix from an existing t-string literal, consider passing along the FString::flags field. If you don’t have an existing literal but have a Checker from the ruff_linter crate available, consider using Checker::default_tstring_flags to create instances of this struct; this method will properly handle nested t-strings. For usage that doesn’t fit into one of these categories, the public constructor TStringFlags::empty can be used.

Implementations

Source

impl TStringFlags

pub fn empty() -> Self

Construct a new TStringFlags with no flags set.

See TStringFlags::with_quote_style, TStringFlags::with_triple_quotes, and TStringFlags::with_prefix for ways of setting the quote style (single or double), enabling triple quotes, and adding prefixes (such as r), respectively.

See the documentation for TStringFlags for additional caveats on this constructor, and situations in which alternative ways to construct this struct should be used, especially when writing lint rules.

pub fn with_quote_style(self, quote_style: Quote) -> Self

pub fn with_triple_quotes(self, triple_quotes: TripleQuotes) -> Self

pub fn with_unclosed(self, unclosed: bool) -> Self

pub fn with_prefix(self, prefix: TStringPrefix) -> Self

pub const fn prefix(self) -> TStringPrefix