Module whitespace

Module whitespace 

Functions

indentation
Extract the leading indentation from a line.
trailing_comment_start_offset
If a Ranged has a trailing comment, return the index of the hash.
trailing_lines_end
Return the end offset at which the empty lines following a statement.