Utilities for parsing Python docstrings.
Functions
- clean_
space - Replace any non-whitespace characters from an indentation string within a Python docstring.
- leading_
space - Extract the leading whitespace from a line of text within a Python docstring.
- leading_
words - Extract the leading words from a line of text within a Python docstring.