pub enum ExceptHandlerRef<'a> {
ExceptHandler(&'a ExceptHandlerExceptHandler),
}Expand description
See also excepthandler
Variants
ExceptHandler(&'a ExceptHandlerExceptHandler)
Implementations
Sourceimpl<'a> ExceptHandlerRef<'a>
impl<'a> ExceptHandlerRef<'a>
Sourcepub const fn is_except_handler(&self) -> bool
pub const fn is_except_handler(&self) -> bool
Returns true if self is of variant ExceptHandler.
Sourcepub fn as_except_handler(&self) -> Option<&&'a ExceptHandlerExceptHandler>
pub fn as_except_handler(&self) -> Option<&&'a ExceptHandlerExceptHandler>
Returns Some if self is a reference of variant ExceptHandler, and None otherwise.
Sourcepub fn as_mut_except_handler(
&mut self,
) -> Option<&mut &'a ExceptHandlerExceptHandler>
pub fn as_mut_except_handler( &mut self, ) -> Option<&mut &'a ExceptHandlerExceptHandler>
Returns Some if self is a mutable reference of variant ExceptHandler, and None otherwise.
Sourcepub fn expect_except_handler(self) -> &'a ExceptHandlerExceptHandlerwhere
Self: Debug,
pub fn expect_except_handler(self) -> &'a ExceptHandlerExceptHandlerwhere
Self: Debug,
Unwraps the value, yielding the content of ExceptHandler.
Panics
Panics if the value is not ExceptHandler, with a panic message including the content of self.
Sourcepub fn except_handler(self) -> Option<&'a ExceptHandlerExceptHandler>
pub fn except_handler(self) -> Option<&'a ExceptHandlerExceptHandler>
Returns Some if self is of variant ExceptHandler, and None otherwise.