AnyStringPrefix

Enum AnyStringPrefix 

pub enum AnyStringPrefix {
    Bytes(ByteStringPrefix),
    Format(FStringPrefix),
    Template(TStringPrefix),
    Regular(StringLiteralPrefix),
}
Enumeration of all the possible valid prefixes prior to a Python string literal.

Using the as_flags() method on variants of this enum is the recommended way to set *_PREFIX flags from the StringFlags bitflag, as it means that you cannot accidentally set a combination of *_PREFIX flags that would be invalid at runtime in Python.

Variants



Bytes(ByteStringPrefix)

Prefixes that indicate the string is a bytestring



Format(FStringPrefix)

Prefixes that indicate the string is an f-string



Template(TStringPrefix)

Prefixes that indicate the string is a t-string



Regular(StringLiteralPrefix)

All other prefixes

Implementations

Source

impl AnyStringPrefix

pub const fn is_bytes(&self) -> bool

Returns true if self is of variant Bytes.

pub fn as_bytes(&self) -> Option<&ByteStringPrefix>

Returns Some if self is a reference of variant Bytes, and None otherwise.

pub fn as_mut_bytes(&mut self) -> Option<&mut ByteStringPrefix>

Returns Some if self is a mutable reference of variant Bytes, and None otherwise.

pub fn expect_bytes(self) -> ByteStringPrefix
where Self: Debug,

Unwraps the value, yielding the content of Bytes.

Panics

Panics if the value is not Bytes, with a panic message including the content of self.

pub fn bytes(self) -> Option<ByteStringPrefix>

Returns Some if self is of variant Bytes, and None otherwise.

pub const fn is_format(&self) -> bool

Returns true if self is of variant Format.

pub fn as_format(&self) -> Option<&FStringPrefix>

Returns Some if self is a reference of variant Format, and None otherwise.

pub fn as_mut_format(&mut self) -> Option<&mut FStringPrefix>

Returns Some if self is a mutable reference of variant Format, and None otherwise.

pub fn expect_format(self) -> FStringPrefix
where Self: Debug,

Unwraps the value, yielding the content of Format.

Panics

Panics if the value is not Format, with a panic message including the content of self.

pub fn format(self) -> Option<FStringPrefix>

Returns Some if self is of variant Format, and None otherwise.

pub const fn is_template(&self) -> bool

Returns true if self is of variant Template.

pub fn as_template(&self) -> Option<&TStringPrefix>

Returns Some if self is a reference of variant Template, and None otherwise.

pub fn as_mut_template(&mut self) -> Option<&mut TStringPrefix>

Returns Some if self is a mutable reference of variant Template, and None otherwise.

pub fn expect_template(self) -> TStringPrefix
where Self: Debug,

Unwraps the value, yielding the content of Template.

Panics

Panics if the value is not Template, with a panic message including the content of self.

pub fn template(self) -> Option<TStringPrefix>

Returns Some if self is of variant Template, and None otherwise.

pub const fn is_regular(&self) -> bool

Returns true if self is of variant Regular.

pub fn as_regular(&self) -> Option<&StringLiteralPrefix>

Returns Some if self is a reference of variant Regular, and None otherwise.

pub fn as_mut_regular(&mut self) -> Option<&mut StringLiteralPrefix>

Returns Some if self is a mutable reference of variant Regular, and None otherwise.

pub fn expect_regular(self) -> StringLiteralPrefix
where Self: Debug,

Unwraps the value, yielding the content of Regular.

Panics

Panics if the value is not Regular, with a panic message including the content of self.

pub fn regular(self) -> Option<StringLiteralPrefix>

Returns Some if self is of variant Regular, and None otherwise.

Source

impl AnyStringPrefix

pub const fn as_str(self) -> &'static str

pub const fn text_len(self) -> TextSize

pub const fn is_raw(self) -> bool