pub enum AnyStringPrefix {
Bytes(ByteStringPrefix),
Format(FStringPrefix),
Template(TStringPrefix),
Regular(StringLiteralPrefix),
}Expand description
Enumeration of all the possible valid prefixes prior to a Python string literal.
Using the as_flags() method on variants of this enum
is the recommended way to set *_PREFIX flags from the
StringFlags bitflag, as it means that you cannot accidentally
set a combination of *_PREFIX flags that would be invalid
at runtime in Python.
Variants
Bytes(ByteStringPrefix)
Prefixes that indicate the string is a bytestring
Format(FStringPrefix)
Prefixes that indicate the string is an f-string
Template(TStringPrefix)
Prefixes that indicate the string is a t-string
Regular(StringLiteralPrefix)
All other prefixes
Implementations
Sourceimpl AnyStringPrefix
impl AnyStringPrefix
Sourcepub fn as_bytes(&self) -> Option<&ByteStringPrefix>
pub fn as_bytes(&self) -> Option<&ByteStringPrefix>
Returns Some if self is a reference of variant Bytes, and None otherwise.
Sourcepub fn as_mut_bytes(&mut self) -> Option<&mut ByteStringPrefix>
pub fn as_mut_bytes(&mut self) -> Option<&mut ByteStringPrefix>
Returns Some if self is a mutable reference of variant Bytes, and None otherwise.
Sourcepub fn expect_bytes(self) -> ByteStringPrefixwhere
Self: Debug,
pub fn expect_bytes(self) -> ByteStringPrefixwhere
Self: Debug,
Sourcepub fn bytes(self) -> Option<ByteStringPrefix>
pub fn bytes(self) -> Option<ByteStringPrefix>
Returns Some if self is of variant Bytes, and None otherwise.
Sourcepub fn as_format(&self) -> Option<&FStringPrefix>
pub fn as_format(&self) -> Option<&FStringPrefix>
Returns Some if self is a reference of variant Format, and None otherwise.
Sourcepub fn as_mut_format(&mut self) -> Option<&mut FStringPrefix>
pub fn as_mut_format(&mut self) -> Option<&mut FStringPrefix>
Returns Some if self is a mutable reference of variant Format, and None otherwise.
Sourcepub fn expect_format(self) -> FStringPrefixwhere
Self: Debug,
pub fn expect_format(self) -> FStringPrefixwhere
Self: Debug,
Sourcepub fn format(self) -> Option<FStringPrefix>
pub fn format(self) -> Option<FStringPrefix>
Returns Some if self is of variant Format, and None otherwise.
Sourcepub const fn is_template(&self) -> bool
pub const fn is_template(&self) -> bool
Returns true if self is of variant Template.
Sourcepub fn as_template(&self) -> Option<&TStringPrefix>
pub fn as_template(&self) -> Option<&TStringPrefix>
Returns Some if self is a reference of variant Template, and None otherwise.
Sourcepub fn as_mut_template(&mut self) -> Option<&mut TStringPrefix>
pub fn as_mut_template(&mut self) -> Option<&mut TStringPrefix>
Returns Some if self is a mutable reference of variant Template, and None otherwise.
Sourcepub fn expect_template(self) -> TStringPrefixwhere
Self: Debug,
pub fn expect_template(self) -> TStringPrefixwhere
Self: Debug,
Sourcepub fn template(self) -> Option<TStringPrefix>
pub fn template(self) -> Option<TStringPrefix>
Returns Some if self is of variant Template, and None otherwise.
Sourcepub const fn is_regular(&self) -> bool
pub const fn is_regular(&self) -> bool
Returns true if self is of variant Regular.
Sourcepub fn as_regular(&self) -> Option<&StringLiteralPrefix>
pub fn as_regular(&self) -> Option<&StringLiteralPrefix>
Returns Some if self is a reference of variant Regular, and None otherwise.
Sourcepub fn as_mut_regular(&mut self) -> Option<&mut StringLiteralPrefix>
pub fn as_mut_regular(&mut self) -> Option<&mut StringLiteralPrefix>
Returns Some if self is a mutable reference of variant Regular, and None otherwise.
Sourcepub fn expect_regular(self) -> StringLiteralPrefixwhere
Self: Debug,
pub fn expect_regular(self) -> StringLiteralPrefixwhere
Self: Debug,
Sourcepub fn regular(self) -> Option<StringLiteralPrefix>
pub fn regular(self) -> Option<StringLiteralPrefix>
Returns Some if self is of variant Regular, and None otherwise.